@@ -11,19 +11,19 @@ package Image::ExifTool::APP12;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.03';
+$VERSION = '1.05';
 
 sub ProcessAPP12($$$);
 
-# APP12 tags
+# APP12 tags (ref PH)
 %Image::ExifTool::APP12::Main = (
     PROCESS_PROC => \&ProcessAPP12,
-    GROUPS => { 0 => 'APP12', 1 => 'APP12', 2 => 'Image' },
+    GROUPS => { 0 => 'APP12', 1 => 'PictureInfo', 2 => 'Image' },
     NOTES => q{
-The JPEG APP12 segment was used by some older cameras, and may contain
-ASCII-based meta information.  Below are some tags which have been observed
-Agfa and Polaroid images, however ExifTool will extract information from any
-tags found in this segment.
+        The JPEG APP12 "Picture Info" segment was used by some older cameras, and
+        contains ASCII-based meta information.  Below are some tags which have been
+        observed Agfa and Polaroid images, however ExifTool will extract information
+        from any tags found in this segment.
     },
     FNumber => {
         ValueConv => '$val=~s/^[A-Za-z ]*//;$val',  # Agfa leads with an 'F'
@@ -82,8 +82,40 @@ tags found in this segment.
     ID          => { Groups => { 2 => 'Camera' } },
 );
 
+# APP12 segment written in Photoshop "Save For Web" images
+# (from tests with Photoshop 7 files - PH)
+%Image::ExifTool::APP12::Ducky = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 0 => 'APP12', 1 => 'Ducky', 2 => 'Image' },
+    FORMAT => 'int16s',
+    FIRST_ENTRY => 0,
+    NOTES => q{
+        Photoshop uses the JPEG APP12 "Ducky" segment to store some information in
+        "Save for Web" images.
+    },
+    # 0 = 1 in all my samples
+    # 1 = 4 in all my samples
+    # 2 = 0 in all my samples
+    3 => { #PH
+        Name => 'Quality',
+        Priority => 0,
+        PrintConv => '"$val%"',
+    },
+    # 4 = 0 if no copyright string, 3 otherwise (maybe number of integers to follow?)
+    # ---- the following is only present if #4 above is 3 ----
+    # 5 = number of bytes in copyright string, including character count #7 and null terminator
+    # 6 = 0 in all my samples
+    # 7 = number of unicode characters in copyright string, excluding null terminator
+    8 => {
+        Name => 'Copyright',
+        Format => 'undef[$size-16]',
+        Groups => { 2 => 'Author' },
+        ValueConv => '$self->Unicode2Byte($val)',
+    },
+);
+
 #------------------------------------------------------------------------------
-# Process APP12 segment
+# Process APP12 segment (ref PH)
 # Inputs: 0) ExifTool object reference, 1) Directory information ref, 2) tag table ref
 # Returns: 1 on success, 0 if this wasn't a recognized APP12
 sub ProcessAPP12($$$)
