@@ -15,6 +15,7 @@
 #               7) Michael Meissner private communication
 #               8) Shingo Noguchi, PhotoXP (http://www.daifukuya.com/photoxp/)
 #               9) Mark Dapoz private communication
+#              10) Lilo Huang private communication (E-330)
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Olympus;
@@ -24,7 +25,7 @@ use vars qw($VERSION);
 use Image::ExifTool::Exif;
 use Image::ExifTool::APP12;
 
-$VERSION = '1.26';
+$VERSION = '1.32';
 
 my %offOn = ( 0 => 'Off', 1 => 'On' );
 
@@ -60,7 +61,7 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
     },
     0x0081 => {
         Name => 'PreviewImageData',
-        ValueConv => '\$val',
+        Binary => 1,
         Writable => 0,
     },
     0x0088 => {
@@ -82,8 +83,7 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
         Name => 'ThumbnailImage',
         Writable => 'undef',
         WriteCheck => '$self->CheckImage(\$val)',
-        ValueConv => '\$val',
-        ValueConvInv => '$val',
+        Binary => 1,
     },
     0x0101 => {
         Name => 'ColorMode',
@@ -147,7 +147,6 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
     },
     0x0201 => {
         Name => 'Quality',
-        Description => 'Image Quality',
         Writable => 'int16u',
         Notes => q{
             Quality values are decoded based on the CameraType tag. All types
@@ -241,12 +240,10 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
         Writable => 'string',
     },
     0x0280 => { #PH
-        Name => 'PreviewImage',
-        Notes => 'Epson ERF preview image',
+        %Image::ExifTool::previewImageTagInfo,
+        Notes => 'found in ERF and JPG images from some Epson models',
         Format => 'undef',
         Writable => 'int8u',
-        ValueConv => '$self->ValidateImage(\$val,"PreviewImage")',
-        ValueConvInv => '$val',
     },
     0x0300 => { #6
         Name => 'PreCaptureFrames',
@@ -276,12 +273,12 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
     0x0f00 => {
         Name => 'DataDump',
         Writable => 0,
-        ValueConv => '\$val',
+        Binary => 1,
     },
     0x0f01 => { #6
         Name => 'DataDump2',
         Writable => 0,
-        ValueConv => '\$val',
+        Binary => 1,
     },
     0x1000 => { #6
         Name => 'ShutterSpeedValue',
@@ -587,9 +584,9 @@ my %offOn = ( 0 => 'Off', 1 => 'On' );
 %Image::ExifTool::Olympus::TextInfo = (
     PROCESS_PROC => \&Image::ExifTool::APP12::ProcessAPP12,
     NOTES => q{
-This information is in text format (similar to APP12 information, but with
-spaces instead of linefeeds).  Below are tags which have been observed, but
-any information found here will be extracted, even if the tag is not listed.
+        This information is in text format (similar to APP12 information, but with
+        spaces instead of linefeeds).  Below are tags which have been observed, but
+        any information found here will be extracted, even if the tag is not listed.
     },
     GROUPS => { 0 => 'MakerNotes', 1 => 'Olympus', 2 => 'Image' },
     Resolution => { },
@@ -1304,6 +1301,7 @@ any information found here will be extracted, even if the tag is not listed.
     # 0x301 Related to inverse of focus distance
     0x305 => { #4
         Name => 'FocusDistance',
+        Writable => 'rational64u',
         # this rational value looks like it is in mm when the denominator is
         # 1 (E-1), and cm when denominator is 10 (E-300), so if we ignore the
         # denominator we are consistently in mm - PH
@@ -1395,6 +1393,7 @@ any information found here will be extracted, even if the tag is not listed.
     0x600 => 'BlackLevel2',
     0x601 => {
         Name => 'YCbCrCoefficients',
+        Notes => 'stored as int16u[6], but extracted as rational32u[3]',
         Format => 'rational32u',
     },
     0x611 => 'ValidPixelDepth',
@@ -1458,7 +1457,7 @@ any information found here will be extracted, even if the tag is not listed.
 );
 
 # add our composite tags
-Image::ExifTool::AddCompositeTags('Image::ExifTool::Olympus::Composite');
+Image::ExifTool::AddCompositeTags(\%Image::ExifTool::Olympus::Composite);
 
 
 #------------------------------------------------------------------------------
@@ -1517,11 +1516,16 @@ sub PrintLensInfo($$)
             '0 24'  => 'Zuiko Digital 14-45mm F3.5-5.6',
             '0 32'  => 'Zuiko Digital 35mm F3.5 Macro', #9
             '0 34'  => 'Zuiko Digital 17.5-45mm F3.5-5.6', #9
+            '0 35'  => 'Zuiko Digital ED 14-42mm F3.5-5.6', #PH
+            '0 36'  => 'Zuiko Digital ED 40-150mm F4.0-5.6', #PH
             # Sigma lenses
             '1 1'   => '18-50mm F3.5-5.6', #8
             '1 2'   => '55-200mm F4.0-5.6 DC',
             '1 3'   => '18-125mm F3.5-5.6 DC',
             '1 4'   => '18-125mm F3.5-5.6', #7
+            '1 5'   => '30mm F1.4', #10
+            '1 7'   => '105mm F2.8 DG', #PH
+            '1 8'   => '150mm F2.8 DG HSM', #PH
         },
         Extender => {
             # Olympus extenders
@@ -1535,9 +1539,14 @@ sub PrintLensInfo($$)
     );
     my $make = $make{$info[0]} || "Unknown Make ($info[0])";
     my $str = "$info[0] $info[2]";
-    my $model = $model{$type}->{"$str $info[3]"} || $model{$type}->{$str} || "Unknown Model ($str)";
     my $rel = $release{$info[3]};
-    $rel = " Unknown Release ($info[3])" unless defined $rel;
+    my $model = $model{$type}->{"$str $info[3]"};
+    if ($model) {
+        $rel = '';  # don't print release if it is used to differentiate models
+    } else {
+        $rel = " Unknown Release ($info[3])" unless defined $rel;
+        $model = $model{$type}->{$str} || "Unknown Model ($str)";
+    }
     return "$make $model$rel";
 }
 
